@@ -31,6 +31,7 @@
 #include <mapnik/geometry.hpp>
 #include <mapnik/geometry_type.hpp>
 #include <mapnik/geometry_centroid.hpp>
+#include <mapnik/geometry/interior.hpp>
 #include <mapnik/vertex_processor.hpp>
 #include <mapnik/geom_util.hpp>
 #include <mapnik/parse_path.hpp>
@@ -40,6 +41,10 @@
 #include <mapnik/text/placement_finder_impl.hpp>
 #include <mapnik/text/placements/base.hpp>
 #include <mapnik/text/placements/dummy.hpp>
+#include <mapnik/geometry_transform.hpp>
+#include <mapnik/geometry_strategy.hpp>
+#include <mapnik/proj_strategy.hpp>
+#include <mapnik/view_strategy.hpp>
 
 namespace mapnik {
 namespace geometry {
@@ -288,9 +293,19 @@ void base_symbolizer_helper::initialize_points() const
             }
             else if (how_placed == INTERIOR_PLACEMENT && type == geometry::geometry_types::Polygon)
             {
-                auto const& poly = mapnik::util::get<geometry::polygon<double> >(geom);
-                geometry::polygon_vertex_adapter<double> va(poly);
-                success = label::interior_position(va, label_x, label_y);
+                auto const& poly = util::get<geometry::polygon<double>>(geom);
+                proj_transform backwart_transform(prj_trans_.dest(), prj_trans_.source());
+                view_strategy vs(t_);
+                proj_strategy ps(backwart_transform);
+                using transform_group_type = geometry::strategy_group<proj_strategy, view_strategy>;
+                transform_group_type transform_group(ps, vs);
+                geometry::polygon<double> tranformed_poly(geometry::transform<double>(poly, transform_group));
+                geometry::point<double> pt;
+                if (geometry::interior(tranformed_poly, scale_factor_, pt))
+                {
+                    points_.emplace_back(pt.x, pt.y);
+                }
+                continue;
             }
             else
             {
